<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../uicilibris.ui" line="14"/>
        <source>UICI LIBRIS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="32"/>
        <source>Drop area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="35"/>
        <source>this tab is for Wiki code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="38"/>
        <source>this tab is for Wiki code. It accepts pasting, and also drag/drops.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="46"/>
        <source>you can select a part of the code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="49"/>
        <source>When a selection is done, the conversion to LaTeX is done with that selection only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="181"/>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="82"/>
        <source>Converts the selected wikicode to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="85"/>
        <source>&amp;Text to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="69"/>
        <source>Converts the selected wikilinks to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="72"/>
        <source>&amp;Links to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="108"/>
        <source>Click here to edit the base address of the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="111"/>
        <source>Click &apos;Base MediaWiki&apos;s address&apos; to edit the base address of the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="127"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="154"/>
        <source>Latex code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="157"/>
        <source>This tab is for LaTeX code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="160"/>
        <source>The LaTeX code in this tab will be compiled with pdflatex upon request.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="171"/>
        <source>modification is possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="174"/>
        <source>modification is possible prior to running pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="187"/>
        <source>Click here to begin a compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="190"/>
        <source>Click &apos;Run PdfLatex&apos; to begin a compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="193"/>
        <source>&amp;Run PdfLatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="200"/>
        <source>Click here to view the generated PDF file when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="203"/>
        <source>Click &apos;View PDF&apos; to view the generated PDF file when available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="206"/>
        <source>&amp;View PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="216"/>
        <source>Opens a Terminal to hack the source in a temporary environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="219"/>
        <source>Hack LaTeX source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="226"/>
        <source>Click here to browse the log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="229"/>
        <source>Click here to browse the log file output by pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="232"/>
        <source>Browse logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="258"/>
        <source>Latex Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="261"/>
        <source>This tab displays the log file output by pdflatex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="264"/>
        <source>After a run of pdftlatex, errors and warnings emitted during the compilation can be searched in this tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="279"/>
        <source>Find</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="297"/>
        <source>Type a string (or select it in a list) to search it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="300"/>
        <source>Type a string in the combo box (or select it in the combo&apos;s list) to search it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="310"/>
        <source>Click here to find the next occurence of the searched string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="313"/>
        <source>Click &apos;Next&apos; to find the next occurence of the searched string</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="316"/>
        <source>Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="329"/>
        <source>Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="332"/>
        <source>This tab is for errors raised by Uicilibris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="335"/>
        <source>Uicilibris can detect a few errors. They are reported in this tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="365"/>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="375"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="386"/>
        <source>&amp;Quit (Ctrl-Q)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="389"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="394"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="399"/>
        <source>User &amp;manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="402"/>
        <source>F1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="114"/>
        <source>Base</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="245"/>
        <source>&amp;Export to another mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris.ui" line="242"/>
        <source>exports text and image files from the cache</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>export</name>
    <message>
        <location filename="../export.py" line="66"/>
        <source>No check of mediawiki has been performed yet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="67"/>
        <source>The current mediawiki has been checked as INVALID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="68"/>
        <source>The current mediawiki has been checked as VALID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="70"/>
        <source>Mediawiki&apos;s validity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="77"/>
        <source>No information about login available yet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="78"/>
        <source>You are not logged in the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="79"/>
        <source>You are logged in the mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="81"/>
        <source>Authentification state</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="122"/>
        <source>You are not logged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="125"/>
        <source>You are logged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="128"/>
        <source>Authentification state undecided</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="142"/>
        <source>The website is not a mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="145"/>
        <source>The website is a mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.py" line="148"/>
        <source>Validity state undecided</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>exportDialog</name>
    <message>
        <location filename="../export.ui" line="14"/>
        <source>Export parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="27"/>
        <source>Mediawiki&apos;s URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="50"/>
        <source>Name Space</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="79"/>
        <source>Validation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="184"/>
        <source>Make checks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="37"/>
        <source>URL of the mediawiki&apos;s homepage. Begins with &apos;http://&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="60"/>
        <source>A short word with a colon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="66"/>
        <source>New:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="181"/>
        <source>Make a few checks in the target mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="86"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="93"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="103"/>
        <source>Your login in this mediawiki</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../export.ui" line="113"/>
        <source>Your password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>uicilibris</name>
    <message>
        <location filename="../uicilibris" line="211"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="257"/>
        <source>Expanding to LaTeX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="406"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="291"/>
        <source>Links to LaTeX processing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="339"/>
        <source>processing &apos;%1&apos; ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="384"/>
        <source>Pdflatex failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="384"/>
        <source>For some reason, Pdflatex failed.&lt;b /&gt;Try to hack around.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="406"/>
        <source>Getting images ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="408"/>
        <source>LaTeX compilation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="421"/>
        <source>getting &apos;%1&apos; ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="439"/>
        <source>Cannot open PDF file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="439"/>
        <source>There is no reachable PDF file. Compile the LaTeX source, or check the error tab.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="451"/>
        <source>Cannot find the temporary files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="451"/>
        <source>There is no temporary files. Please run Pdflatex.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../__init__.py" line="166"/>
        <source>À propos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="90"/>
        <source>Style = Wiki to Book</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="91"/>
        <source>Style = Wiki to Article</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="92"/>
        <source>Style = Wiki to Beamer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="288"/>
        <source>Connection to the mediawiki ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="352"/>
        <source>Feature not yet implemented</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../uicilibris" line="352"/>
        <source>The feature &apos;%1&apos; is not yet implemented. Report a bug to the developers.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
